# okta_jwt

Okta JWT Access Token verifier for Python using cached JWKs.

## Installation

    $ pip install okta_jwt

## Usage

## Development

## Contributing

Bug reports and Pull Requests(PR's) are welcome on GitHub at https://github.com/adithyasampatoor/okta_jwt. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The Library is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT)

## Thanks

This library was originally based heavily on the work of the folks over at 'python-jose'.
